@@ -27,6 +27,8 @@ from .._util import (
     LoggingFileHandler,
     compose_coroutines,
     pathsize,
+    link_force,
+    symlink_force,
 )
 from .._util import StructuredLogMessage as _
 from . import config, _statusbar
@@ -87,7 +89,7 @@ def run_local_task(
             )
         logger.notice(  # pyre-fixme
             _(
-                "task start",
+                "task setup",
                 name=task.name,
                 source=task.pos.uri,
                 line=task.pos.line,
@@ -218,16 +220,30 @@ def run_local_task(
                     cache.put(cache_key, outputs)
                 return (run_dir, outputs)
         except Exception as exn:
-            logger.debug(traceback.format_exc())
+            tbtxt = traceback.format_exc()
+            logger.debug(tbtxt)
             wrapper = RunFailed(task, run_id, run_dir)
-            logmsg = _(str(wrapper), dir=run_dir, **error_json(exn))
+            logmsg = _(
+                str(wrapper),
+                dir=run_dir,
+                **error_json(
+                    exn, traceback=tbtxt if not isinstance(exn, Error.RuntimeError) else None
+                ),
+            )
             if isinstance(exn, Terminated) and getattr(exn, "quiet", False):
                 logger.debug(logmsg)
             else:
                 logger.error(logmsg)
             try:
                 write_atomic(
-                    json.dumps(error_json(wrapper, cause=exn), indent=2),
+                    json.dumps(
+                        error_json(
+                            wrapper,
+                            cause=exn,
+                            traceback=tbtxt if not isinstance(exn, Error.RuntimeError) else None,
+                        ),
+                        indent=2,
+                    ),
                     os.path.join(run_dir, "error.json"),
                 )
             except Exception as exn2:
@@ -780,11 +796,11 @@ def link_outputs(
                 if hardlinks:
                     # TODO: what if target is an input from a different filesystem?
                     if isinstance(v, Value.Directory):
-                        shutil.copytree(target, link, symlinks=True, copy_function=os.link)
+                        shutil.copytree(target, link, symlinks=True, copy_function=link_force)
                     else:
-                        os.link(target, link)
+                        link_force(target, link)
                 else:
-                    os.symlink(target, link)
+                    symlink_force(target, link)
                 # Drop a dotfile indicating whether this is a File/Directory output, to inform a
                 # program crawling the out/ directory without reference to the JSON output for
                 # whatever reason. It might otherwise have trouble distinguishing File and
